package com.bonus.material.settlement.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.settlement.domain.SltAgreementRelation;
import com.bonus.material.settlement.service.ISltAgreementRelationService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 计算关系Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "计算关系接口")
@RestController
@RequestMapping("/slt_agreement_relation")
public class SltAgreementRelationController extends BaseController {
    @Autowired
    private ISltAgreementRelationService sltAgreementRelationService;

    /**
     * 查询计算关系列表
     */
    @ApiOperation(value = "查询计算关系列表")
    @RequiresPermissions("settlement:relation:list")
    @GetMapping("/list")
    public TableDataInfo list(SltAgreementRelation sltAgreementRelation) {
        startPage();
        List<SltAgreementRelation> list = sltAgreementRelationService.selectSltAgreementRelationList(sltAgreementRelation);
        return getDataTable(list);
    }

    /**
     * 导出计算关系列表
     */
    @ApiOperation(value = "导出计算关系列表")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:relation:export")
    @SysLog(title = "计算关系", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出计算关系")
    @PostMapping("/export")
    public void export(HttpServletResponse response, SltAgreementRelation sltAgreementRelation) {
        List<SltAgreementRelation> list = sltAgreementRelationService.selectSltAgreementRelationList(sltAgreementRelation);
        ExcelUtil<SltAgreementRelation> util = new ExcelUtil<SltAgreementRelation>(SltAgreementRelation.class);
        util.exportExcel(response, list, "计算关系数据");
    }

    /**
     * 获取计算关系详细信息
     */
    @ApiOperation(value = "获取计算关系详细信息")
    @RequiresPermissions("settlement:relation:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(sltAgreementRelationService.selectSltAgreementRelationById(id));
    }

    /**
     * 新增计算关系
     */
    @ApiOperation(value = "新增计算关系")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:relation:add")
    @SysLog(title = "计算关系", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增计算关系")
    @PostMapping
    public AjaxResult add(@RequestBody SltAgreementRelation sltAgreementRelation) {
        try {
            return toAjax(sltAgreementRelationService.insertSltAgreementRelation(sltAgreementRelation));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改计算关系
     */
    @ApiOperation(value = "修改计算关系")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:relation:edit")
    @SysLog(title = "计算关系", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改计算关系")
    @PutMapping
    public AjaxResult edit(@RequestBody SltAgreementRelation sltAgreementRelation) {
        try {
            return toAjax(sltAgreementRelationService.updateSltAgreementRelation(sltAgreementRelation));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除计算关系
     */
    @ApiOperation(value = "删除计算关系")
    @PreventRepeatSubmit
    @RequiresPermissions("settlement:relation:remove")
    @SysLog(title = "计算关系", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除计算关系")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(sltAgreementRelationService.deleteSltAgreementRelationByIds(ids));
    }
}
